summaryrefslogtreecommitdiff
path: root/ubi-utils/include/libmtd.h
diff options
context:
space:
mode:
Diffstat (limited to 'ubi-utils/include/libmtd.h')
-rw-r--r--ubi-utils/include/libmtd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ubi-utils/include/libmtd.h b/ubi-utils/include/libmtd.h
index 2d7d451..242ecf5 100644
--- a/ubi-utils/include/libmtd.h
+++ b/ubi-utils/include/libmtd.h
@@ -39,7 +39,7 @@ extern "C" {
* @eb_size: eraseblock size
* @min_io_size: minimum input/output unit size
* @subpage_size: sub-page size
* @rdonly: non-zero if the device is read-only
* @bb_allowed: non-zero if the MTD device may have bad eraseblocks
*/
struct mtd_dev_info
@@ -54,7 +54,7 @@ struct mtd_dev_info
int eb_size;
int min_io_size;
int subpage_size;
- unsigned int rdonly:1;
+ unsigned int writable:1;
unsigned int bb_allowed:1;
};
@@ -39,7 +39,7 @@ extern "C" {
* @min_io_size: minimum input/output unit size
* @subpage_size: sub-page size
- * @rdonly: non-zero if the device is read-only
+ * @writable: zero if the device is read-only
* @bb_allowed: non-zero if the MTD device may have bad eraseblocks
*/